|
From: <bo...@us...> - 2008-02-16 08:13:20
|
Revision: 67
http://gearbox.svn.sourceforge.net/gearbox/?rev=67&view=rev
Author: borax00
Date: 2008-02-16 00:13:25 -0800 (Sat, 16 Feb 2008)
Log Message:
-----------
general clean-up.
Modified Paths:
--------------
gearbox/trunk/submitted/gbxserialacfr/doc.dox
gearbox/trunk/submitted/gbxserialacfr/gbxserialacfr.h
gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.cpp
gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.h
gearbox/trunk/submitted/gbxserialacfr/lockfile/test/CMakeLists.txt
gearbox/trunk/submitted/gbxserialacfr/lockfile/test/locktest.cpp
gearbox/trunk/submitted/gbxserialacfr/serial.cpp
gearbox/trunk/submitted/gbxserialacfr/serial.h
gearbox/trunk/submitted/gbxserialacfr/test/CMakeLists.txt
gearbox/trunk/submitted/gbxserialacfr/test/serialechotest.cpp
gearbox/trunk/submitted/gbxserialacfr/test/serialloopbacktest.cpp
gearbox/trunk/submitted/gbxserialacfr/uncopyable.h
gearbox/trunk/submitted/gbxsickacfr/CMakeLists.txt
gearbox/trunk/submitted/gbxsickacfr/doc.dox
gearbox/trunk/submitted/gbxsickacfr/driver.cpp
gearbox/trunk/submitted/gbxsickacfr/driver.h
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/buffer.h
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/gbxiceutilacfr.h
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.h
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.h
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.h
gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/gbxserialdeviceacfr.h
gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/gbxutilacfr.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/mathdefs.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/status.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/substatus.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/tracer.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.h
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.cpp
gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.h
gearbox/trunk/submitted/gbxsickacfr/messages.cpp
gearbox/trunk/submitted/gbxsickacfr/messages.h
gearbox/trunk/submitted/gbxsickacfr/serialhandler.cpp
gearbox/trunk/submitted/gbxsickacfr/serialhandler.h
gearbox/trunk/submitted/gbxsickacfr/test/test.cpp
Modified: gearbox/trunk/submitted/gbxserialacfr/doc.dox
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/doc.dox 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/doc.dox 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,12 +1,13 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
- * Copyright (c) 2004-2008 Mathew Ridley, Alex Brooks
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Mathew Ridley
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
*
*/
+
/*!
@ingroup gbx_libs
@ingroup gbx_cpp
@@ -18,22 +19,27 @@
C++ class wrapping a serial port. For a full list of functions and classes see @ref gbxserialacfr.
-Header file:
+@par Header file
+
@verbatim
#include <gbxserialacfr/serial.h>
@endverbatim
-Other serial libraries:
-- http://libserial.sourceforge.net (GPL)
-- http://qextserialport.sourceforge.net (requires Qt)
+@par Other serial libraries
+ - http://libserial.sourceforge.net (GPL)
+ - http://qextserialport.sourceforge.net (requires Qt)
+
@par Tested On
- rs232 only (ie not rs422)
- For USB-to-serial devices, tested on FTDI-based devices only
+@par Copyright
+ Alex Brooks, Mathew Ridley
+
@par Responsible Developer
-Alex Brooks
+ Alex Brooks
*/
Modified: gearbox/trunk/submitted/gbxserialacfr/gbxserialacfr.h
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/gbxserialacfr.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/gbxserialacfr.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,7 +1,7 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
- * Copyright (c) 2004-2008 Mathew Ridley, Alex Brooks
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Mathew Ridley
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
Modified: gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.cpp
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.h
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/lockfile/lockfile.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxserialacfr/lockfile/test/CMakeLists.txt
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/lockfile/test/CMakeLists.txt 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/lockfile/test/CMakeLists.txt 2008-02-16 08:13:25 UTC (rev 67)
@@ -2,3 +2,4 @@
ADD_EXECUTABLE( locktest locktest.cpp )
TARGET_LINK_LIBRARIES( locktest GbxLockFileAcfr )
+GBX_ADD_TEST( GbxLockFileAcfr locktest )
\ No newline at end of file
Modified: gearbox/trunk/submitted/gbxserialacfr/lockfile/test/locktest.cpp
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/lockfile/test/locktest.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/lockfile/test/locktest.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,3 +1,13 @@
+/*
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks
+ *
+ * This distribution is licensed to you under the terms described in
+ * the LICENSE file included in this distribution.
+ *
+ */
+
#include <iostream>
#include <cstdlib>
#include <gbxserialacfr/lockfile/lockfile.h>
Modified: gearbox/trunk/submitted/gbxserialacfr/serial.cpp
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/serial.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/serial.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,7 +1,7 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
- * Copyright (c) 2004-2008 Mathew Ridley, Alex Brooks
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Mathew Ridley
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
Modified: gearbox/trunk/submitted/gbxserialacfr/serial.h
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/serial.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/serial.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,7 +1,7 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
- * Copyright (c) 2004-2008 Mathew Ridley, Alex Brooks
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Mathew Ridley
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
Modified: gearbox/trunk/submitted/gbxserialacfr/test/CMakeLists.txt
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/test/CMakeLists.txt 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/test/CMakeLists.txt 2008-02-16 08:13:25 UTC (rev 67)
@@ -3,5 +3,4 @@
LINK_LIBRARIES( GbxSerialAcfr )
GBX_ADD_EXECUTABLE( serialechotest serialechotest.cpp )
-
GBX_ADD_EXECUTABLE( serialloopbacktest serialloopbacktest.cpp )
Modified: gearbox/trunk/submitted/gbxserialacfr/test/serialechotest.cpp
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/test/serialechotest.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/test/serialechotest.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -10,6 +10,7 @@
//
// A simple utility program for testing serial ports.
+// Listens for incoming data, echoes it to the terminal.
//
std::string
Modified: gearbox/trunk/submitted/gbxserialacfr/test/serialloopbacktest.cpp
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/test/serialloopbacktest.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/test/serialloopbacktest.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -11,6 +11,8 @@
//
// A simple utility program for testing serial ports in loopback.
+// Put the port in loopback (ie connect pins 2 & 3), then type stuff.
+// It should be echoed back on the terminal.
//
std::vector<std::string>
Modified: gearbox/trunk/submitted/gbxserialacfr/uncopyable.h
===================================================================
--- gearbox/trunk/submitted/gbxserialacfr/uncopyable.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxserialacfr/uncopyable.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,7 +1,7 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
- * Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
Modified: gearbox/trunk/submitted/gbxsickacfr/CMakeLists.txt
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/CMakeLists.txt 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/CMakeLists.txt 2008-02-16 08:13:25 UTC (rev 67)
@@ -15,15 +15,13 @@
SET( int_libs GbxUtilAcfr GbxIceUtilAcfr GbxSerialDeviceAcfr )
IF ( build )
- # allow subdir's to include themselves and each other
-# INCLUDE_DIRECTORIES( ${CMAKE_CURRENT_SOURCE_DIR} )
ADD_SUBDIRECTORY( gbxutilacfr )
ADD_SUBDIRECTORY( gbxiceutilacfr )
ADD_SUBDIRECTORY( gbxserialdeviceacfr )
INCLUDE( ${GBX_CMAKE_DIR}/UseBasicRules.cmake )
-# INCLUDE( ${GBX_CMAKE_DIR}/UseIceUtil.cmake )
+ INCLUDE( ${GBX_CMAKE_DIR}/UseIceUtil.cmake )
FILE( GLOB hdrs *.h )
FILE( GLOB srcs *.cpp )
Modified: gearbox/trunk/submitted/gbxsickacfr/doc.dox
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/doc.dox 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/doc.dox 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
@@ -9,31 +9,48 @@
*/
/*!
-@ingroup hydro_drivers_laserscanner2d
-@ingroup hydro_cpp
-@ingroup hydro_linux
-@defgroup hydro_driver_laserscanner2dsickacfr LaserScanner2dSickAcfr
+@ingroup gbx_drivers_laserscanner2d
+@ingroup gbx_cpp
+@ingroup gbx_linux
+@defgroup gbx_driver_laserscanner2dsickacfr LaserScanner2dSickAcfr
@brief ACFR driver for SICK laser range-finder.
Drives SICK hardware, directly connected to the computer.
+@par Header file
+
+@verbatim
+#include <gbxsickacfr/driver.h>
+@endverbatim
+
+@par Example
+ See test/test.cpp
+
+@par Copyright
+ Alex Brooks, Alexei Makarenko, Tobias Kaupp
+
+@par Responsible Developer
+ Alex Brooks
+
@par Dependencies
- libIceUtil (for timing/threads/mutexes)
-- libHydroSerial and libHydroSerialDevice
+- libGbxSerialAcfr
@par Limitations
-
+
- This is a Linux-only implementation.
- It has not been tested at 500k baud.
+- It has only been tested on the LMS-291
-@par Extra configuration
+*/
-- @c SickAcfr.Device (string)
- - The unix device to use
- - Default: "/dev/ttyS0"
-- @c SickAcfr.Baudrate (int) [bps]
- - Valid Values: { 9600, 19200, 38400, 500000 }
- - Default: 38400
+/*!
+@brief SICK laser driver
+@namespace gbxsickacfr
-*/
+This namespace is part of a SICK laser driver
+
+@see @ref gbx_library_gbxsickacfr
+
+*/
\ No newline at end of file
Modified: gearbox/trunk/submitted/gbxsickacfr/driver.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/driver.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/driver.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/driver.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/driver.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/driver.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/buffer.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/buffer.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/buffer.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/gbxiceutilacfr.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/gbxiceutilacfr.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/gbxiceutilacfr.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/subsystemthread.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,10 +1,10 @@
/*
-Orca Project: Components for robotics
- http://orca-robotics.sf.net/
-Copyright (c) 2004-2007 Alex Brooks, Alexei Makarenko, Tobias Kaupp
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
-This copy of Orca is licensed to you under the terms described in the
-ORCA_LICENSE file included in this distribution.
+ * This distribution is licensed to you under the terms described in
+ * the LICENSE file included in this distribution.
*
*/
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/thread.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,10 +1,10 @@
/*
-Orca Project: Components for robotics
- http://orca-robotics.sf.net/
-Copyright (c) 2004-2007 Alex Brooks, Alexei Makarenko, Tobias Kaupp
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
-This copy of Orca is licensed to you under the terms described in the
-ORCA_LICENSE file included in this distribution.
+ * This distribution is licensed to you under the terms described in
+ * the LICENSE file included in this distribution.
*
*/
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxiceutilacfr/timer.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/gbxserialdeviceacfr.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/gbxserialdeviceacfr.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/gbxserialdeviceacfr.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxserialdeviceacfr/serialdevicehandler.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/gbxutilacfr.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/gbxutilacfr.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/mathdefs.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/mathdefs.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/mathdefs.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/status.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/status.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/status.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/substatus.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/substatus.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/substatus.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/tracer.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/tracer.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/tracer.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialstatus.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/trivialtracer.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
Modified: gearbox/trunk/submitted/gbxsickacfr/messages.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/messages.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/messages.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,12 +1,13 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
*
*/
+
#include "messages.h"
#include <cstring>
#include <iostream>
Modified: gearbox/trunk/submitted/gbxsickacfr/messages.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/messages.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/messages.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,12 +1,13 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
*
*/
+
#ifndef SICK_ACFR_DRIVER_MESSAGES_H
#define SICK_ACFR_DRIVER_MESSAGES_H
Modified: gearbox/trunk/submitted/gbxsickacfr/serialhandler.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/serialhandler.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/serialhandler.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,12 +1,13 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
*
*/
+
#include "serialhandler.h"
#include <iostream>
Modified: gearbox/trunk/submitted/gbxsickacfr/serialhandler.h
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/serialhandler.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/serialhandler.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,12 +1,13 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks
*
* This distribution is licensed to you under the terms described in
* the LICENSE file included in this distribution.
*
*/
+
#ifndef SICK_ACFR_SERIALHANDLER_H
#define SICK_ACFR_SERIALHANDLER_H
Modified: gearbox/trunk/submitted/gbxsickacfr/test/test.cpp
===================================================================
--- gearbox/trunk/submitted/gbxsickacfr/test/test.cpp 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/test/test.cpp 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,3 +1,13 @@
+/*
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
+ * Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
+ *
+ * This distribution is licensed to you under the terms described in
+ * the LICENSE file included in this distribution.
+ *
+ */
+
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
@@ -13,14 +23,14 @@
using namespace std;
-
+//
+// Instantiates the laser driver, reads a few scans
+//
int main( int argc, char **argv )
{
int opt;
-// int baud = 115200;
-// bool useSerial = false;
+ int baud = 38400;
string port = "/dev/ttyS0";
- int maxCount = 1;
// Get some options from the command line
while ((opt = getopt (argc, argv, "p:c:")) != -1)
@@ -28,53 +38,38 @@
switch (opt)
{
case 'p':
-// strncpy (port, optarg, 256);
port = optarg;
break;
- case 'c':
- maxCount = atoi( optarg );
+ case 'b':
+ baud = atoi (optarg);
break;
-// case 'b':
-// baud = atoi (optarg);
-// if (baud != 19200 && baud != 57600 && baud != 115200)
-// {
-// printf ("Baud rate must be one of 19200, 57600 or 115200.\n");
-// return 1;
-// }
-// break;
-// case 's':
-// useSerial = true;
-// break;
default:
- printf ("Usage: %s [-p port] [-b baud] [-s]\n\n"
- "-p port\tPort the laser scanner is connected to. E.g. /dev/ttyS0\n"
- "-b baud\tBaud rate to connect at (19200, 57600 or 115200).\t"
- "-s\tUse RS232 connection instead of USB.\n", argv[0]);
+ cout << "Usage: " << argv[0] << " [-p port] [-b baud]" << endl << endl
+ << "-p port\tPort the laser scanner is connected to. E.g. /dev/ttyS0" << endl
+ << "-b baud\tBaud rate to connect at (19200, 57600 or 115200)." << endl;
return 1;
}
}
-
+ // Set up the laser's configuration
gbxsickacfr::Config config;
-
config.minRange = 0.0;
config.maxRange = 80.0;
config.fieldOfView = 180.0*DEG2RAD_RATIO;
config.startAngle = -90.0*DEG2RAD_RATIO;
config.numberOfSamples = 181;
- config.baudRate = 38400;
+ config.baudRate = baud;
config.device = port;
+ if ( !config.validate() ) {
+ cout << "Test: Invalid laser configuration: " << config.toString() << endl;
+ }
+ cout << "Using configuration: " << config.toString() << endl;
+ // Instantiate objects to handle messages from the driver
gbxsickacfr::gbxutilacfr::TrivialTracer tracer;
gbxsickacfr::gbxutilacfr::TrivialStatus status( tracer );
- if ( !config.validate() ) {
- tracer.error( "Test: Failed to validate laser configuration. "+config.toString() );
- }
-
- tracer.info( "Validated configuration structure: "+config.toString() );
-
- // initialize
+ // Instantiate the driver itself
gbxsickacfr::Driver* device;
try
{
@@ -82,47 +77,34 @@
}
catch ( const std::exception& e )
{
- stringstream ss; ss<<"Test: Failed to init device: "<<e.what();
- tracer.error( ss.str() );
+ cout <<"Test: Failed to init device: "<<e.what() << endl;
return 1;
}
- // allocated data storage
- vector<float> ranges;
- vector<unsigned char> intensities;
- ranges.resize( config.numberOfSamples );
- intensities.resize( config.numberOfSamples );
-
- // create data structure
+ // Create data structure to store sensor data
+ vector<float> ranges( config.numberOfSamples );
+ vector<unsigned char> intensities( config.numberOfSamples );
gbxsickacfr::Data data;
data.ranges = &(ranges[0]);
data.intensities = &(intensities[0]);
- int count = 0;
- while ( count < maxCount )
+ // Read a few times
+ const int numReads = 3;
+ for ( int i=0; i < numReads; i++ )
{
- // catch exceptions!!!
try
{
- // using default timeout of 1000ms
device->read( data );
}
catch ( const std::exception& e )
{
- stringstream ss; ss<<"Test: Failed to read scan: "<<e.what();
- tracer.error( ss.str() );
+ cout <<"Test: Failed to read scan: "<<e.what()<<endl;
}
- // data.timeStampSec;
- // data.timeStampUsec;
-
- stringstream ss; ss<<"Test: Got scan "<<count+1<<" of "<<maxCount;
- tracer.info( ss.str() );
+ cout<<"Test: Got scan "<<i+1<<" of "<<numReads<<endl;
if ( data.haveWarnings )
- tracer.warning( "got warnings: "+data.warnings );
-
- count++;
+ cout << "got warnings: " << data.warnings << endl;
}
return 0;
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.h 2008-02-16 06:56:16 UTC (rev 66)
+++ gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/exceptions.h 2008-02-16 08:13:25 UTC (rev 67)
@@ -1,6 +1,6 @@
/*
- * Orca-Robotics Project: Components for robotics
- * http://orca-robotics.sf.net/
+ * GearBox Project: Peer-Reviewed Open-Source Libraries for Robotics
+ * http://gearbox.sf.net/
* Copyright (c) 2004-2008 Alex Brooks, Alexei Makarenko, Tobias Kaupp
*
* This distribution is licensed to you under the terms described in
@@ -22,7 +22,7 @@
#define ERROR_MACROS_HPP_
#if defined(STRINGIZE_HELPER) || defined(STRINGIZE) || defined(ERROR_INFO)
# error HydroUtil error macros have already been defined elsewhere
#endif
#define STRINGIZE_HELPER(exp) #exp
@@ -39,7 +39,7 @@
namespace gbxutilacfr {
/*!
-@brief Base class for all Hydro exceptions.
+@brief Base class for all GbxUtilAcfr exceptions.
Can be caught as a std::exception due to inheritance.
Modified: gearbox/trunk/submitted/gbxsickacfr/gbxutilacfr/gbxutilacfr.h
===================================================================
@@ -22,7 +22,7 @@
#define ERROR_MACROS_HPP_
#if defined(STRINGIZE_HELPER) || defined(STRINGIZE) || defined(ERROR_INFO)
-# error HydroUtil error macros have already been defined elsewhere
+# error GbxUtilAcfr error macros have already been defined elsewhere
#endif
#define STRINGIZE_HELPER(exp) #exp